# 开发指南

## 安装

从 GitHub 克隆项目：
```
git clone https://github.com/QuantumAlgorithm/QuantumAlgorithm.git
```

以可编辑模式安装 qalgo：
```
pip install -e .
```

安装开发依赖：
```
pip install -r requirements.txt
```

## 测试
```
pytest
```

## 提交
commitizen

## 文档
```
mkdocs serve
```
在浏览器中访问。

## 发布
本项目通过 GitHub Actions 自动发布到 PyPI。
